@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 # from RFC 1893
 
@@ -592,34 +592,252 @@ die "Can't generate list_smtp_statuses function: $res->[0] - $res->[1]"
     unless $res->[0] == 200;
 
 1;
-# ABSTRACT: List STMP statuses
-
+# ABSTRACT: List SMTP statuses
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-App::smtpstatus - List STMP statuses
+App::smtpstatus - List SMTP statuses
 
 =head1 VERSION
 
-version 0.01
+This document describes version 0.02 of App::smtpstatus (from Perl distribution App-smtpstatus), released on 2014-07-22.
+
+=head1 FUNCTIONS
+
+
+=head2 list_smtp_statuses(%args) -> [status, msg, result, meta]
+
+List SMTP statuses.
+
+REPLACE ME
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<code> => I<str>
+
+Only return records where the 'code' field equals specified value.
+
+=item * B<code.contains> => I<str>
+
+Only return records where the 'code' field contains specified text.
+
+=item * B<code.in> => I<array>
+
+Only return records where the 'code' field is in the specified values.
+
+=item * B<code.is> => I<str>
+
+Only return records where the 'code' field equals specified value.
+
+=item * B<code.isnt> => I<str>
+
+Only return records where the 'code' field does not equal specified value.
+
+=item * B<code.max> => I<str>
+
+Only return records where the 'code' field is less than or equal to specified value.
+
+=item * B<code.min> => I<str>
+
+Only return records where the 'code' field is greater than or equal to specified value.
+
+=item * B<code.not_contains> => I<str>
+
+Only return records where the 'code' field does not contain specified text.
+
+=item * B<code.not_in> => I<array>
+
+Only return records where the 'code' field is not in the specified values.
+
+=item * B<code.xmax> => I<str>
+
+Only return records where the 'code' field is less than specified value.
+
+=item * B<code.xmin> => I<str>
+
+Only return records where the 'code' field is greater than specified value.
+
+=item * B<description> => I<str>
+
+Only return records where the 'description' field equals specified value.
+
+=item * B<description.contains> => I<str>
+
+Only return records where the 'description' field contains specified text.
+
+=item * B<description.in> => I<array>
+
+Only return records where the 'description' field is in the specified values.
+
+=item * B<description.is> => I<str>
+
+Only return records where the 'description' field equals specified value.
+
+=item * B<description.isnt> => I<str>
+
+Only return records where the 'description' field does not equal specified value.
+
+=item * B<description.max> => I<str>
+
+Only return records where the 'description' field is less than or equal to specified value.
+
+=item * B<description.min> => I<str>
+
+Only return records where the 'description' field is greater than or equal to specified value.
+
+=item * B<description.not_contains> => I<str>
+
+Only return records where the 'description' field does not contain specified text.
+
+=item * B<description.not_in> => I<array>
+
+Only return records where the 'description' field is not in the specified values.
+
+=item * B<description.xmax> => I<str>
+
+Only return records where the 'description' field is less than specified value.
+
+=item * B<description.xmin> => I<str>
+
+Only return records where the 'description' field is greater than specified value.
+
+=item * B<detail> => I<bool> (default: 0)
+
+Return array of full records instead of just ID fields.
+
+By default, only the key (ID) field is returned per result entry.
+
+=item * B<fields> => I<array>
+
+Select fields to return.
+
+=item * B<q> => I<str>
+
+Search.
+
+=item * B<random> => I<bool> (default: 0)
+
+Return records in random order.
+
+=item * B<result_limit> => I<int>
+
+Only return a certain number of records.
+
+=item * B<result_start> => I<int> (default: 1)
+
+Only return starting from the n'th record.
+
+=item * B<sort> => I<str>
+
+Order records according to certain field(s).
+
+A list of field names separated by comma. Each field can be prefixed with '-' to
+specify descending order instead of the default ascending.
+
+=item * B<summary> => I<str>
+
+Only return records where the 'summary' field equals specified value.
+
+=item * B<summary.contains> => I<str>
+
+Only return records where the 'summary' field contains specified text.
+
+=item * B<summary.in> => I<array>
+
+Only return records where the 'summary' field is in the specified values.
+
+=item * B<summary.is> => I<str>
+
+Only return records where the 'summary' field equals specified value.
+
+=item * B<summary.isnt> => I<str>
+
+Only return records where the 'summary' field does not equal specified value.
+
+=item * B<summary.max> => I<str>
+
+Only return records where the 'summary' field is less than or equal to specified value.
+
+=item * B<summary.min> => I<str>
+
+Only return records where the 'summary' field is greater than or equal to specified value.
+
+=item * B<summary.not_contains> => I<str>
+
+Only return records where the 'summary' field does not contain specified text.
+
+=item * B<summary.not_in> => I<array>
+
+Only return records where the 'summary' field is not in the specified values.
+
+=item * B<summary.xmax> => I<str>
+
+Only return records where the 'summary' field is less than specified value.
+
+=item * B<summary.xmin> => I<str>
+
+Only return records where the 'summary' field is greater than specified value.
+
+=item * B<with_field_names> => I<bool>
+
+Return field names in each record (as hash/associative array).
+
+When enabled, function will return each record as hash/associative array
+(field name => value pairs). Otherwise, function will return each record
+as list/array (field value, field value, ...).
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+ (any)
 
 =head1 SEE ALSO
 
 RFC 1893
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/App-smtpstatus>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-App-smtpstatus>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-smtpstatus>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
